"""
datatypedialog.py
GUI to add/edit/remove dataTypes
NOTE: Cannot remove or change dataTypes that already have channels.
"""

from sohstationviewer.view.db_config.db_config_dialog import UiDBInfoDialog
from sohstationviewer.database.proccessDB import executeDB


class DataTypeDialog(UiDBInfoDialog):
    def __init__(self, parent):
        super().__init__(parent, ['No.', 'DataType'], 'dataType', 'dataTypes',
                         resize_content_columns=[0])
        self.setWindowTitle("Edit/Add/Delete DataTypes")

    def add_row(self, row_idx, fk=False):
        """
        Add a row of widgets to self.data_table_widgets.

        :param row_idx: index of row to add
        :param fk: bool: True if there is a foreign constrain that prevents the
            row to be deleted
        """
        self.add_widget(None, row_idx, 0)  # No.
        self.add_widget(self.data_list, row_idx, 1, foreign_key=fk)

    def get_data_list(self):
        """
        Get list of data to fill self.data_table_widgets' content
        """

        data_type_rows = executeDB('SELECT * FROM DataTypes')
        return [[d[0]] for d in data_type_rows]

    def get_row_inputs(self, row_idx):
        """
        Get content from a row of widgets

        :param row_idx: index of row
        """
        return [self.data_table_widget.cellWidget(row_idx, 1).text().strip()]

    def update_data(self, row, widget_idx, list_idx):
        """
        Prepare insert, update queries then update data of a row from
            self.data_table_widgets' content.

        :param row: list - data of a row
        :param widget_idx: index of row in self.data_table_widgets
        :param list_idx: index of row in self.data_list
        """
        insert_sql = f"INSERT INTO DataTypes VALUES('{row[0]}')"
        update_sql = (f"UPDATE DataTypes SET dataType='{row[0]}' "
                      f"WHERE dataType='%s'")

        return super().update_data(
            row, widget_idx, list_idx, insert_sql, update_sql)
